@@ -1,3 +1,4 @@
+from __future__ import absolute_import
 import json
 from sqlalchemy.types import TypeDecorator
 from sqlalchemy.types import VARCHAR
@@ -12,7 +13,7 @@ class Mapping(TypeDecorator):
 
     Please note that this does not support any of the operators available
     for the `PostgreSQL HSTORE type
-    <http://docs.sqlalchemy.org/en/rel_0_9/dialects/postgresql.html#sqlalchemy.dialects.postgresql.HSTORE`_
+    <http://docs.sqlalchemy.org/en/rel_0_9/dialects/postgresql.html#sqlalchemy.dialects.postgresql.HSTORE>`_
     on other dialects.
     """
 
