@@ -66,7 +66,7 @@ class GUIDTests(unittest.TestCase):
         import uuid
         guid = self.GUID()
         output = guid.process_result_value(self.test_uuid, None)
-        self.assertTrue(isinstance(output, type(b'')))
+        self.assertTrue(isinstance(output, type('')))
         self.assertEqual(str(output), self.test_uuid)
 
     def test_process_result_value_uuid_value(self):
@@ -74,5 +74,5 @@ class GUIDTests(unittest.TestCase):
         import uuid
         guid = self.GUID()
         output = guid.process_result_value(uuid.UUID(self.test_uuid), None)
-        self.assertTrue(isinstance(output, type(b'')))
+        self.assertTrue(isinstance(output, type('')))
         self.assertEqual(str(output), self.test_uuid)
